@@ -1,13 +1,13 @@
-# Copyrights 2007-2015 by [Mark Overmeer].
+# Copyrights 2007-2016 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.01.
+# Pod stripped from pm file by OODoc 2.02.
 use warnings;
 use strict;
 
 package XML::Compile::SOAP::Daemon::NetServer;
 use vars '$VERSION';
-$VERSION = '3.11';
+$VERSION = '3.12';
 
 
 # The selected type of netserver gets added to the @ISA during new(),
@@ -123,7 +123,7 @@ sub setWsdlResponse($;$)
 sub log($$@)
 {   my ($self, $level, $msg) = (shift, shift, shift);
     $msg = sprintf $msg, @_ if @_;
-    $msg =~ s/\n$//g;  # some log lines have a trailing newline
+    chomp $msg;  # some log lines have a trailing newline
 
     my $reason = $levelToReason[$level] or return;
     report $reason => $msg;
